---
tags: #untagged, #not-blogged
---

# Admin Pages

## Top Level Includes

* [[Sidebar|/_Sidebar]]
* [[Footer|/_Footer]]
* [[Header|/_Header]]

## Project Page Includes

* [[Sidebar|/projects/_Sidebar]]
* [[Footer|/projects/_Footer]]
* [[Header|/projects/_Header]] 

## Pages to Process

* [[untagged pages|http://wiki2.thespacedoctor.co.uk/search?q=%23untagged]]
* [[pages to send to blog?|http://wiki2.thespacedoctor.co.uk/search?q=%23not-blogged]]
